@@ -6,7 +6,7 @@ local search = require("luarocks.search")
 local queries = require("luarocks.queries")
 local fs = require("luarocks.fs")
 local dir = require("luarocks.dir")
-local cfg = require("luarocks.core.cfg")
+local util = require("luarocks.util")
 
 local function get_file(filename)
    local protocol, pathname = dir.split_url(filename)
@@ -22,9 +22,9 @@ local function get_file(filename)
    end
 end
 
-function download.download(arch, name, version, all)
+function download.download(arch, name, namespace, version, all, check_lua_versions)
    local substring = (all and name == "")
-   local query = queries.new(name, version, substring, arch)
+   local query = queries.new(name, namespace, version, substring, arch)
    local search_err
 
    if all then
@@ -54,13 +54,13 @@ function download.download(arch, name, version, all)
       end
    else
       local url
-      url, search_err = search.find_suitable_rock(query)
+      url, search_err = search.find_rock_checking_lua_versions(query, check_lua_versions)
       if url then
          return get_file(url)
       end
    end
-   return nil, "Could not find a result named "..name..(version and " "..version or "")..
-      (search_err and ": "..search_err or ".")
+   local rock = util.format_rock_name(name, namespace, version)
+   return nil, "Could not find a result named "..rock..(search_err and ": "..search_err or ".")
 end
 
 return download
