@@ -10,6 +10,8 @@ local cfg = require("luarocks.core.cfg")
 local dir = require("luarocks.dir")
 local util = require("luarocks.util")
 
+local pack = table.pack or function(...) return { n = select("#", ...), ... } end
+
 local socket_ok, zip_ok, lfs_ok, md5_ok, posix_ok, bz2_ok, _
 local http, ftp, zip, lfs, md5, posix, bz2
 
@@ -54,7 +56,9 @@ end
 
 local function quote_args(command, ...)
    local out = { command }
-   for _, arg in ipairs({...}) do
+   local args = pack(...)
+   for i=1, args.n do
+      local arg = args[i]
       assert(type(arg) == "string")
       out[#out+1] = fs.Q(arg)
    end
@@ -807,7 +811,7 @@ local function http_request(url, filename, http, cache)
       local timestamp = read_timestamp(filename..".timestamp")
       if status or timestamp then
          local unixtime = read_timestamp(filename..".unixtime")
-         if unixtime then
+         if tonumber(unixtime) then
             local diff = os.time() - tonumber(unixtime)
             if status then
                if diff < cfg.cache_fail_timeout then
@@ -905,8 +909,11 @@ function fs_lua.download(url, filename, cache)
       err = "Unsupported protocol"
    end
    if https_err then
+      local downloader, err = fs.which_tool("downloader")
+      if not downloader then
+         return nil, err
+      end
       if not downloader_warning then
-         local downloader = fs.which_tool("downloader")
          util.warning("falling back to "..downloader.." - install luasec to get native HTTPS support")
          downloader_warning = true
       end
